# -*- coding: utf-8 -*-
"""
Created on Wed Mar 31 20:59:08 2021

@author: M.ABDELMOULA
"""

from IronTranslator.constants import LANGUAGES_CODES, LANGUAGES_NAMES, MAIN_LINK, SPECIAL_CHAR
from IronTranslator.GoogleTranslate import Translator
